Setuptools 'scrutinize' Command
===============================


This package creates **scrutinize** as a command in setup.py.

It will execute different code analysis tools, e.g. `pylint`.


Installation
------------

This package is published on pypi. You can use pip to install it.

::

    pip install setuptools-scrutinize


Usage
-----

::

    python setup.py scrutinize


For a full list of options, do

::

  python setup.py scrutinize --help

.. _`pylint` : http://pypi.python.org/pypi/pylint
